![](./assets/hydrapy-logo.png)

# Hydra-Py
Hydra for Python. A light-weight library for building distributed applications such as microservices.

```diff
- NOTE THIS PROJECT IS IN VERY EARLY DEVELOPMENT
```
- Hydra-Py is changing quickly and not recommended for serious use at this time
* As a microservices approach, Hydra-Py depends on the presence of a Redis database server as its single infrastructual dependency
* Hydra-Py requires Python 3.7+ and aioredis==1.3.1 or greater

## Introduction
Hydra is an approach to building light-weight microservices by leveraging the awesome power of the Redis database platform.

> Hydra-Py is a nextgen port of the NodeJS implementation of Hydra with a goal of offering the same level of ease of use to the Python community.  We hope this will empower data scientists to build containerized microservices for their AI/ML applications.

## Documentation
Visit the [project documentation](https://github.com/pnxtech/HydraPy/tree/master/documentation) for a quick start guide and additional documentation.

